"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.makeTestEnvironment = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _core = require("@resolve-js/core");

var _runtime = require("@resolve-js/runtime");

var _assertions = require("../../utils/assertions");

var _getSecretsManager = require("../../runtime/get-secrets-manager");

var _getEventStore = require("../../runtime/get-event-store");

var makeTestEnvironment = function makeTestEnvironment(context) {
  var executed = false;
  var authToken;
  var assertion;
  var secretsManager = (0, _getSecretsManager.getSecretsManager)();
  var completeTest;
  var failTest;

  var setAuthToken = function setAuthToken(value) {
    authToken = value;
  };

  var setSecretsManager = function setSecretsManager(value) {
    secretsManager = value;
  };

  var setAssertion = function setAssertion(value) {
    assertion = value;
  };

  var getAssertion = function getAssertion() {
    return assertion;
  };

  var isExecuted = function isExecuted() {
    return executed;
  };

  var promise = new Promise(function (resolve, reject) {
    completeTest = resolve;
    failTest = reject;
  });

  var execute = /*#__PURE__*/function () {
    var _ref = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee() {
      var aggregate, events, command, _context$aggregateId, aggregateId, domain, executor, actualAssertion, commandResult, testResult;

      return _regenerator["default"].wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              executed = true;
              aggregate = context.aggregate, events = context.events, command = context.command, _context$aggregateId = context.aggregateId, aggregateId = _context$aggregateId === void 0 ? 'test-aggregate-id' : _context$aggregateId;
              domain = (0, _core.initDomain)({
                viewModels: [],
                readModels: [],
                aggregates: [{
                  name: aggregate.name,
                  projection: aggregate.projection,
                  commands: aggregate.commands,
                  encryption: aggregate.encryption || null,
                  deserializeState: JSON.parse,
                  serializeState: JSON.stringify,
                  invariantHash: 'invariant-hash'
                }],
                sagas: []
              });
              executor = null;
              actualAssertion = assertion != null ? assertion : _assertions.defaultAssertion;
              _context.prev = 5;
              _context.t0 = _runtime.createCommand;
              _context.t1 = domain.aggregateDomain;
              _context.next = 10;
              return (0, _getEventStore.getEventStore)(events, {
                aggregateId: aggregateId
              });

            case 10:
              _context.t2 = _context.sent;
              _context.t3 = secretsManager;
              _context.t4 = {};
              _context.t5 = {
                eventstore: _context.t2,
                secretsManager: _context.t3,
                hooks: _context.t4
              };
              _context.t6 = _context.t1.acquireAggregatesInterop.call(_context.t1, _context.t5);
              _context.t7 = {
                performanceTracer: null,
                aggregatesInterop: _context.t6
              };
              executor = (0, _context.t0)(_context.t7);
              _context.next = 19;
              return executor({
                aggregateId: aggregateId,
                aggregateName: aggregate.name,
                type: command.name,
                payload: command.payload || {},
                jwt: authToken
              });

            case 19:
              commandResult = _context.sent;
              testResult = {
                type: commandResult.type
              };

              if (Object.prototype.hasOwnProperty.call(commandResult, 'payload')) {
                testResult.payload = commandResult.payload;
              }

              return _context.abrupt("return", actualAssertion(completeTest, failTest, testResult, null, false));

            case 25:
              _context.prev = 25;
              _context.t8 = _context["catch"](5);
              return _context.abrupt("return", actualAssertion(completeTest, failTest, null, _context.t8, false));

            case 28:
              _context.prev = 28;

              if (!executor) {
                _context.next = 32;
                break;
              }

              _context.next = 32;
              return executor.dispose();

            case 32:
              return _context.finish(28);

            case 33:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[5, 25, 28, 33]]);
    }));

    return function execute() {
      return _ref.apply(this, arguments);
    };
  }();

  setImmediate(execute);
  return {
    setAuthToken: setAuthToken,
    setSecretsManager: setSecretsManager,
    setAssertion: setAssertion,
    getAssertion: getAssertion,
    isExecuted: isExecuted,
    promise: promise
  };
};

exports.makeTestEnvironment = makeTestEnvironment;
//# sourceMappingURL=make-test-environment.js.map