"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.stringify = stringify;
exports.stringifyShouldExecuteSideEffectFailure = exports.stringifyShouldExecuteQueryFailure = exports.stringifyShouldExecuteCommandFailure = exports.stringifyDiff = exports.stringifyError = void 0;

var _diff = require("diff");

var _colors = _interopRequireDefault(require("colors"));

var _os = _interopRequireDefault(require("os"));

var stringifyError = function stringifyError(error) {
  return error == null ? 'no error' : error.toString();
};

exports.stringifyError = stringifyError;

var stringifyDiff = function stringifyDiff(expected, result) {
  return (0, _diff.diffJson)(expected, result, {
    undefinedReplacement: '<undefined>'
  }).map(function (change) {
    var color = _colors["default"].gray;
    var prefix = '';

    if (change.added) {
      color = _colors["default"].green;
      prefix = '+';
    } else if (change.removed) {
      color = _colors["default"].red;
      prefix = '-';
    }

    return color("" + prefix + change.value);
  }).join('');
};

exports.stringifyDiff = stringifyDiff;

var isExecutedSideEffect = function isExecutedSideEffect(value) {
  return Array.isArray(value) && value.length > 0 && typeof value[0] === 'string';
};

function stringify(item) {
  if (isExecutedSideEffect(item)) {
    var name = item[0],
        args = item.slice(1);
    return name + "(" + args.map(function (arg) {
      return JSON.stringify(arg);
    }).join(',') + ")";
  }

  return JSON.stringify(item, null, 2);
}

var stringifyShouldExecuteFailure = function stringifyShouldExecuteFailure(name, expected, executed) {
  return name + " assertion failed:" + _colors["default"].green(_os["default"].EOL + "Expected:" + _os["default"].EOL + stringify(expected)) + _os["default"].EOL + "Executed:" + _os["default"].EOL + executed.map(function (executedItem, index) {
    return _colors["default"].red("#" + index + ":" + _os["default"].EOL + stringify(executedItem));
  }).join(_os["default"].EOL);
};

var stringifyShouldExecuteCommandFailure = function stringifyShouldExecuteCommandFailure(expectedCommand, executedCommands) {
  return stringifyShouldExecuteFailure('shouldExecuteCommand', expectedCommand, executedCommands);
};

exports.stringifyShouldExecuteCommandFailure = stringifyShouldExecuteCommandFailure;

var stringifyShouldExecuteQueryFailure = function stringifyShouldExecuteQueryFailure(expectedQuery, executedQueries) {
  return stringifyShouldExecuteFailure('shouldExecuteQuery', expectedQuery, executedQueries);
};

exports.stringifyShouldExecuteQueryFailure = stringifyShouldExecuteQueryFailure;

var stringifyShouldExecuteSideEffectFailure = function stringifyShouldExecuteSideEffectFailure(expectedSideEffect, executedSideEffects) {
  return stringifyShouldExecuteFailure('shouldExecuteSideEffect', expectedSideEffect, executedSideEffects);
};

exports.stringifyShouldExecuteSideEffectFailure = stringifyShouldExecuteSideEffectFailure;
//# sourceMappingURL=format.js.map